@@ -109,7 +109,7 @@ kpTransformResizeScaleDialog::kpTransformResizeScaleDialog (
     baseLayout->addWidget(operationGroupBox);
     baseLayout->addWidget(dimensionsGroupBox);
 
-    KConfigGroup cfg(KSharedConfig::openConfig(), kpSettingsGroupGeneral);
+    KConfigGroup cfg(KSharedConfig::openConfig(), QStringLiteral(kpSettingsGroupGeneral));
     setKeepAspectRatio(cfg.readEntry(kpSettingResizeScaleLastKeepAspect, false));
     m_lastType = static_cast<kpTransformResizeScaleCommand::Type>
                    (cfg.readEntry(kpSettingResizeScaleScaleType,
@@ -827,7 +827,7 @@ void kpTransformResizeScaleDialog::accept ()
     }
 
     // store settings
-    KConfigGroup cfg(KSharedConfig::openConfig(), kpSettingsGroupGeneral);
+    KConfigGroup cfg(KSharedConfig::openConfig(), QStringLiteral(kpSettingsGroupGeneral));
 
     cfg.writeEntry(kpSettingResizeScaleLastKeepAspect, m_keepAspectRatioCheckBox->isChecked());
     cfg.writeEntry(kpSettingResizeScaleScaleType, static_cast<int>(m_lastType));
