@@ -152,11 +152,7 @@ bool kpDocument::urlExists (const QUrl &url) const
     if (url.isEmpty()) {
         return false;
     }
-#if KIO_VERSION >= QT_VERSION_CHECK(5, 240, 0)
     KIO::StatJob *job = KIO::stat(url, KIO::StatJob::SourceSide, KIO::StatNoDetails);
-#else
-    KIO::StatJob *job = KIO::statDetails(url, KIO::StatJob::SourceSide, KIO::StatNoDetails);
-#endif    
     KJobWidgets::setWindow (job, d->environ->dialogParent ());
     return job->exec();
 }
