@@ -287,7 +287,7 @@ void kpFloodFill::findAndAddLines (const kpFillLine &fillLine, int dy)
 
     for (int xnow = fillLine.m_x1; xnow <= fillLine.m_x2; xnow++)
     {
-        // At current position, right colour?
+        // At current position, right color?
         if (shouldGoTo (xnow, fillLine.m_y + dy))
         {
             // Find minimum and maximum x values
@@ -352,7 +352,7 @@ void kpFloodFill::prepare ()
 
     for (int i = 0; i < d->fillLines.count(); i++)
     {
-      kpFillLine &fl = d->fillLines[i];
+      kpFillLine fl = d->fillLines[i];
 
     #if DEBUG_KP_FLOOD_FILL && 0
         qCDebug(kpLogImagelib) << "Expanding from y=" << fl.m_y
