@@ -77,13 +77,13 @@ bool SaneDialog::setup()
 
     // restore scan dialog size and all options for the selected device if available
     KSharedConfigPtr configPtr = KSharedConfig::openConfig(QStringLiteral("scannersettings"));
-    KWindowConfig::restoreWindowSize(windowHandle(), KConfigGroup(configPtr, "ScanDialog"));
+    KWindowConfig::restoreWindowSize(windowHandle(), KConfigGroup(configPtr, QStringLiteral("ScanDialog")));
     QString groupName = m_openDev;
     if (configPtr->hasGroup(groupName)) {
         KConfigGroup group(configPtr, groupName);
         QStringList keys = group.keyList();
         for (int i = 0; i < keys.count(); i++) {
-            m_ksanew->setOptVal(keys[i], group.readEntry(keys[i]));
+            m_ksanew->setOptionValue(keys[i], group.readEntry(keys[i]));
         }
     }
 
@@ -95,11 +95,11 @@ SaneDialog::~SaneDialog()
     if (m_ksanew && !m_openDev.isEmpty()) {
         // save scan dialog size and all options for the selected device if available
         KSharedConfigPtr configPtr = KSharedConfig::openConfig(QStringLiteral("scannersettings"));
-        KConfigGroup group(configPtr, "ScanDialog");
+        KConfigGroup group(configPtr, QStringLiteral("ScanDialog"));
         KWindowConfig::saveWindowSize(windowHandle(), group, KConfigGroup::Persistent);
         group = configPtr->group(m_openDev);
         QMap<QString, QString> opts;
-        m_ksanew->getOptVals(opts);
+        m_ksanew->getOptionValues(opts);
         QMap<QString, QString>::const_iterator i = opts.constBegin();
         for (; i != opts.constEnd(); ++i) {
             group.writeEntry(i.key(), i.value(), KConfigGroup::Persistent);
