@@ -68,7 +68,7 @@ public:
     kpEffectCommandBase *createCommand (
         kpCommandEnvironment *cmdEnviron) const override;
 
-protected slots:
+protected Q_SLOTS:
     void slotEnableChanged (bool enable);
 
 protected:
